# Enhanced QoS Configuration (Version: SM 5.2.0)

Copyright (c) 2022-2023 NVIDIA CORPORATION & AFFILIATES. All rights reserved.


Enhanced QoS feature introduce extension to standard QoS and allows setting
bandwidth limits, per SL, and per virtual port.


## Configuration

### Enhanced QoS policy file

To define Enhance QoS Configuration file, set *enhanced_qos_policy_file* parameter in
SM configuration, to point to the policy file. 
Set the value to *(null)* in order to disable the feature.

For example:
```
enhanced_qos_policy_file /etc/opensm/conf/enhanced_qos_policy_file
```

## Enhanced QoS policy file 

Enhanced QoS policy file contains the following sections:
- *BW_NAMES* to define bandwidth setting.
- *BW_RULES* to define rules which maps bandwidth settings to specified SL`s of specified GUIDs.

Invalid policy file might result with undefined behavior.
User should verify the correctness of the file, and confirm that there are no relevant errors in SM log file.


### BW_NAMES

The section starts with *BW_NAMES* keyword. 
Each line of BW_NAMES section is in the following format: 
```
<bw_name> = <limit in 1Mbps units>
```
Limit set to 0, means no limit.


The following example defines bandwidth setting named 'bw1' which specifies a limit of 50 Mbps.
```
bw1 = 50
```

### BW_RULES

The section starts with *BW_RULES* keyword. 
Each rule definition line of BW_RULES section is in the following format: 
```
<GUID|port_group|default> = <SL#>:<bw_name>, [<SL#>:<bw_name>…]
```

- GUID - Specific port GUID in hexadecimal format to apply current rule.
- port_group - Apply current rule to all ports in port group defined in pgrp_policy_file.
- *default* - Apply current rule to all GUIDs that has no specific rule.
- SL#:<bw_name> Mapping from specific SL ID to bandwidth definition specified in BW_NAMES section.


The following line defines rule for port with the GUID 0x2c90000000025 to limit the bandwidth 
on SL5 and SL7 to the bandwidth setting named *bw1*.

```
0x2c90000000025 = 5:bw1, 7:bw1
```


### Example

Example for configuring all ports in the fabric with bandwidth limit of 50Mbps on SL 1 except of port GUID 0x2c90000000025 which is configured with BW limit of 100Mbps on SL 1.
All other SLs are not limited.

```
BW_NAMES

bw1 = 50
bw2 = 100

BW_RULES

default = 1:bw1
0x2c90000000025 = 1:bw2

```
