# MLNXSM 5.10.0

Copyright (c) 2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.  
November 2021


## Packages:

| Package | Version     |
| ------- | ----------- |
| UFM     | 6.8.0       |
| MOFED   | 5.5-0.5.7.0 |

## Main features

- Added support for Adaptive Timeout SL mask.  
  Feature control parameter:  
  *adaptive_timeout_sl_mask* - an adaptive timeout enabled SLs mask. (Default *0xFFFF*)

- IB Router QoS  
  Extended the QoS policy file to support subnet prefixes and port GIDs for inter subnet QoS.  
  This improvement enables the definition of SL/rate/MTU/packet-life for cross-subnet paths.  
  For further information, refer to the *doc/QoS_management_in_OpenSM.txt* document.
 
- Added a new root detection algorithm in UPDN and ar_updn routing engines.  
  Feature control parameters:  
  *find_roots_color_algorithm* - enables/disables the feature. (Default is TRUE)  
  *max_cas_on_spine* - sets the maximum number of CAs on a switch to allow considering it  
   as a spine instead of a leaf by the routing algorithm.
 
- Changed the default routing engine to be ar_updn instead of minhop.

- Added support for VS (Vendor Specific) key.  
  Feature control parameters:  
  *vs_key_enable* - enables VS key configuration: 0 - ignore, 1 - disable, 2 - enable.  
  *vs_key_lease_period* - the lease period used for VS keys in [sec].  
  *vs_key_ci_protect_bits* - the protection level for the key:  
  1 - protected, 0 - unprotected (The response Key Info exposes the key).  
  *vs_max_outstanding_mads* - the maximum number of outstanding VS MADs in the network at once.  
  *key_mgr_seed* - used by key manager for VS key configuration.  

- Improved SA response time during routing calculation.  
  Feature control parameter:  
  *enable_queries_during_routing* - enables SA queries during routing calculation. (Default is TRUE)



## Changes

- Report duplicated GUIDs to UFM.

- Added the option to report switch reboots to UFM.

- Enabled the option to use long transaction timeout for PI for port 0 MADs.

- Added subnet prefix to SMDB dump file.

- Added SM binding port information to the MAD details in the timeout message, dumped to the SM log file.

- Added SM start time to the SMDB dump file.

- Added the option to enable dump MAD statistics per SM port.  
  Feature control parameter:  
  - *osm_stats_dump_per_sm_port* - enables/disables the feature. (Default is *FALSE*)

- Made the process of selecting Adaptive Routing (AR) group IDs deterministic in each run of the SM on the same fabric.

## Parameter changes

| Parameter name                | Status | Type    | Description                                                                   |
| ----------------------------- | ------ | ------- | ------------------------------------------------------------------------------|
| adaptive_timeout_sl_mask      | New    | Number  | Defines an adaptive timeout SL mask of the port. Default 0xFFFF               |
| routing_engine                | Update | String  | Changed default value from *(null)* to *ar_updn*                              |
| find_roots_color_algorithm    | New    | Boolean | Find root using coloring algorithm for tree based topologies. Default is TRUE.|
| max_cas_on_spine              | New    | Number  | The maximum number of CAs on a switch to allow considering it as a spine      |
|                               |        |         | instead of a leaf by the routing algorithm.                                   |
| hm_num_traps                  | Update | Number  | Changed default value from *250* to *60*.                                     |
| hm_num_traps_period_secs      | Update | Number  | Changed default value from *60* to *90* seconds.                              |
| vs_key_enable                 | New    | Number  | Parameter for enabling VS key configuration: 0 ignore, 1 disable, 2 enable    |
| vs_key_lease_period           | New    | Number  | The lease period used for VS keys in [sec]                                    |
| vs_key_ci_protect_bits        | New    | Number  | Define the protection level for the key:                                      |
|                               |        |         | 1 - protected, 0 - unprotected (The response Key Info exposes the key).       |
| vs_max_outstanding_mads       | New    | Number  | Maximum number of VS mads in the network at once.                             |
| key_mgr_seed                  | New    | Number  | Used by key manager for VS key configuration.                                 |
| osm_stats_dump_per_sm_port    | New    | Boolean | Enables dump of MAD statistics per SM port. Default is FALSE.                 |
| enable_queries_during_routing | New    | Boolean | Enables SA queries during routing calculation. Default is TRUE.               |



## Bug fixes

- Fixed a crash that occurred during a race between the LFT record get query and routing configuration.

- Fixed the non-generic notices statistics counter in the dump file.

- Fixed the postponing isolation and reporting process of the noisy ports.

- Fixed an issue related to the selecting of the held back/isolated switches as roots for multicast trees.

- Fixed an issue that caused the unresponsive links to to remain in Active state.

- Fixed an issue that affected the writing of invalid AN2AN links to SMDB dump file.

- Fixed IPoIB traffic loss after changing subnet prefix and loading MC groups from SADB on SM restart.

- Fixed the SM build on Debian with libibumad from rdma-core.

- Fixed the way how port capability changes are handled during runtime.

- Fixed an incorrect endianness issue in error log message 0F29.

- Fixed an incorrect log message when enabling SHARP on the device.

- Fixed the statistics counters race condition with SM multi port.

- Fixed rewriting of the statistics file when the existing file had different header than the current.  
  In case the previous header is different from the current,  
  a backup of the old file is created as well as the updated statistics file.

