# MLNXSM 5.8.1

January 2021

Packages:

| Package | Version |
| ------- | ------- |
| UFM     | 6.6.1   |


## Main features

- Support asymmetric tress
  Feature applicable to *ar_updn* and *ar_ftree* routing engines. The feature
  reduces congestion in asymmetric tree topologies with missing uplinks on leaf switches.
  Feature control parameters:
  - *ar_tree_asymmetric_flow* - Enable/disable the feature.
    Supported values:  
    0 - Disable the feature (default).
    1 - Enable the feature using single AR subgroup.
        Recommended for asymmetric tree topologies with 1000-2000 leaf switches.
    2 - Enable the feature using two AR subgroups.
        Recommended for asymmetric tree topologies with less than 1000 leaf switches. 
    
- Support selecting LID for master SM, in order to prevent SM LID change upon fail-over.
  Feature control parameters:
  - *master_sm_lid* - LID for master SM.
    Supported values:
    0 - Disable the feature (default).
    1-0xBFFF - LID to set to SM port when in MASTER state.

- Support for root GUIDs file for DF+ routing engines (*dfp* and *dfp2*).
  Feature control parameters:
  - *root_guid_file* - File with GUIDs of root switches of the topology.

- Support new routing engine (*dfp2*) for DF+ topologies.
  This engine supports DF+ topologies with any kind of tree topology islands.
  If topology contains an island with more than 2 tree levels, root GUIDs file including
  root switches of all DF+ islands should be provided.
  Feature control parameters:
  - *routing_engine* - Extended to support *dfp2*

- Support configuring different *max_op_vls* for CAs, Routers and Switches.
  Feature control parameters:
  - *max_op_vls_ca* - Max operational VLs for CAs. When 0, use value max_op_vls. (default *0*)
  - *max_op_vls_rtr* - Max operational VLs for routers. When 0, use value max_op_vls. (default *0*)
  - *max_op_vls_sw* - Max operational VLs for switches. When 0, use value max_op_vls. (default *0*)

- Support "VL packing" for DF+ and KDOR routing engines.
  Allow reducing max operational VLs for CAs to half of subnet *max_op_vls* when using *dfp*/*dfp2*/*kdor_hc* routing engines.
  Feature control parameters:
  - *enable_vl_packing* - Enable/disable the feature. (default *TRUE*)  

  For example:
  - *enable_vl_packing* set to *TRUE*.
  - *max_op_vls* set to *3* (Enable 4 VLs).
  - *max_op_vls_ca* set to *2* (Use 2 VLs for CAs).

- Enable returning PortInfoRecord and NodeRecord for virtual ports in order to support
  running SRP target on HCAs with socket-direct architecture or on virtual machines.
  Feature control parameters:
  - *enable_virt_rec_ext* - Enable/disable the feature. (default *TRUE*)

- Improve balancing of direct routes calculated for multi-port.

- Set HCA-grp in port groups parser to be optional parameter.

- Support router alias GUIDs configuration for virtual ports.


## Changes

- Add definition of NDR speed port info capability bit to ib_types.h.

- Avoid sending client reregister to vport index 0.

- Extend rpg_byte_reset to 19 bits in Congestion Control.

- Enable crashd by default.

- Increase priority of virt manager over InfromInfo manager.

- Report auxiliary port state changes.

- Override attributes of IPoIB multicast groups loaded from SADB with broadcast group.

- Send discovery PortInfo/MEPI MADs "on the fly".

- Configure switch AR SL mask according to *ar_sl_mask* configuration parameter.

- Update GeneralInfo device IDs list.

- Update man page with AR routing engines.

- Avoid exiting when failing to bind to auxiliary port

- Add "SpecialPortType" to SMDB ports table in order to identify SHARP Aggregation Node ports.


## Parameter changes

| Parameter name                        | Status | Type    | Description                                                  |
| ------------------------------------- | ------ | ------- | ------------------------------------------------------------ |
| max_wire_smps                         | Update | Number  | Change default from 4 to 16                                  |
| max_wire_smps2                        | Update | Number  | Change default from 4 to 16                                  |
| max_smps_timeut                       | Update | Number  | Change default from 600000 to 300000                         |
| max_msg_fifo_timeout                  | Update | Number  | Change default from 10000 to 5000                            |
| transaction_timeout                   | Update | Number  | Change default from 200 to 100                               |
| enable_crashd                         | Update | Boolean | Change default from FALSE to TRUE                            |
| routing_engine                        | Update | Text    | Support *dfp2* routing engine                                |
| master_sm_lid                         | New    | LID     | LID for local SM when in MASTER state                        |
| enable_virt_rec_ext                   | New    | Boolean | Enable PortInfoRecord/NodeRecord for virtual ports/nodes     |
| ar_tree_asymmetric_flow               | New    | Number  | AR Asymmetric trees max flow algorithm                       |
| max_op_vls_ca                         | New    | Number  | max_op_vl for CAs                                            |
| max_op_vls_sw                         | New    | Number  | max_op_vl for switches                                       |
| max_op_vls_rtr                        | New    | Number  | max_op_vl for routers                                        |
| enable_vl_packing                     | New    | Boolean | Enable VL packing                                            |


## Bug fixes

- Allow incoming SA requests with default subnet prefix in GRH.

- Fix crash due to calling virt_mgr on aborted sweep.

- Fix DR when sending GeneralInfo MAD after coming out-of-standby.

- Fix calling memset for class in ar_mgr.

- Fix crash in UPDN LID tracking when multithreading enabled.

- Fix not closing file descriptor when running with crashd.

- Fix potential memory leak in DF+ routing algorithm.

- Fix setting default pkey at index 0 on invalid partitions.conf.

- Skip M_Key lookup for virtualization MADs.

- Fix ar_sl_mask is not deployed on hosts when running with armgr plugin.

- Fix checking ar/plft capabilities of switch with timeouts.

- Fix typo in mcmr_rcv_join_mgrp log message.

- Fix wrong error messages in updn with lid tracking.

- Free alias GUIDs resources when deleting virtual port.

- Fix checking 2x link width capability.

- Support handling MCMemberRecord request with default subnet prefix.

