# OpenSM Security Features

## SA key

### SA Enhanced Trust Model - SAETM

Standard SA has a concept of trust-based requests on the SA_Key that is part of each SA MAD. A trusted request is when the SA_Key value is not equal to zero but equals the SA configured value, while an untrusted request is when the SA_Key value equals zero in the request. If a request has a non-zero SA_Key value that is different from the configured SA key, it will be dropped and reported.

When SAETM is enabled, the SA limits the set of untrusted requests allowed.
Untrusted requests that are not allowed according to SAETM will be silently dropped (for the set of untrusted requests allowed, see section 2 below).

### 1. OpenSM configuration parameters

1.1 sa_enhanced_trust_model -

SAETM feature is disabled by default. To enable it, set the sa_enhanced_trust_model parameter to TRUE.

1.2 sa_etm_allow_untrusted_guidinfo_rec -

Defines whether to allow GUIDInfoRecord as part of the SAETM set of untrusted requests allowed (see SA Key section 2).

1.3 sa_etm_allow_guidinfo_rec_by_vf -

Defines whether to drop GUIDInfoRecord from non-physical ports (see SA Key section 2).

1.4 sa_etm_allow_untrusted_proxy_requests -

Defines the behavior for proxy requests (see SA Key section 3).

1.5 sa_etm_max_num_mcgs/sa_etm_max_num_srvcs/sa_etm_max_num_event_subs -

Defines the registration limits in SAETM (see SA Key section 4).

1.6 sa_check_sgid_spoofing -

See SA Key section 6. SGID Spoofing.

### 2. Set of Untrusted SA Requests Allowed

List of untrusted requests allowed when SAETM is enabled:

1. MCMemberRecord - Get/Set/Delete
2. PathRecord         - Get
3. PathRecord         - GetTable, only if both destination and source are specified (e,g.
                        only point to point)
4. ServiceRecord      - Get/Set/Delete
5. InformInfo         - Set, for non-SM security traps
6. ClassPortInfo      - Get
7. GUIDInfoRecord     - Set/Delete - this request can only be part of this set depending on
                        the values of sa_etm_allow_untrusted_guidinfo_rec and sa_etm_allow_guidinfo_rec_by_vf (see elaboration below).

When sa_etm_allow_untrusted_guidinfo_rec is set to FALSE (and SAETM is enabled), the SA will drop GUIDInfoRecord Set/Delete untrusted requests.
When sa_etm_allow_guidinfo_rec_by_vf is set to FALSE (and SAETM is enabled), the SA will drop GUIDInfoRecord Set/Delete requests from non-physical ports.
In case sa_etm_allow_untrusted_guidinfo_rec is FALSE, GUIDInfoRecord Set/Delete requests will become part of the SAETM set of untrusted requests allowed.
Note that if sa_etm_allow_guidinfo_rec_by_vf is FALSE, the requests will only be allowed from physical ports.

### 3. Proxy SA Requests

SA modification request (SET/DELETE) is identified as a proxy operation when the port corresponding with the requester source address (SLID from LRH / SGID from GRH) is diffident than the port for which the request applies:

For MCMemberRecord, when the MCMemberRecord.PortGID field does not match the requester address.
For ServiceRecord, when the ServiceRecord.ServiceGID field does not match requester address.
For the GUIDInfoRecord, when the LID field in the RID of the record does not match the requester address.

When sa_etm_allow_untrusted_proxy_requests is set to FALSE and SAETM is enabled, untrusted proxy requests will be dropped.

### 4. Registration Limits

When any of sa_etm_max_num_mcgs, sa_etm_max_num_srvcs or sa_etm_max_num_event_subs
parameters is set to 0, the number of this parameters registrations can be unlimited.
When the parameters value is different than 0, attempting to exceed the maximum number of registrations will result in the request being silently dropped.
Consequently, the requester and request info will be logged, and an event will be generated for the Activity Manager.

The following parameters control the maximum number of registrations:

1. sa_etm_max_num_mcgs: Max number of multicast groups per port/vport that can be registered.
2. sa_etm_max_num_srvcs: Max number of service records per port/vport that can be registered.
3. sa_etm_max_num_event_subs: Max number of event subscriptions (InformInfo) per port/vport that can be registered.

Registration limits are valid only when SAETM is enabled.

### 5. SAETM Logging

When requesting an operation that is not part of the SAETM set of untrusted requests, it will be silently dropped and eventually written to the SM log.

The logging of the dropped MADs is repressed to not overload the OpenSM log.
If the request that needs to be dropped was received from the same requester many times consecutively, OpenSM logs it only if the request number is part of the following sequence:
0, 1, 2, 5, 10, 20, 50, 100, 200... (similar to the trap log repression).

### 6. SGID Spoofing

SA can validate requester addresses by comparing the SLID and SGID of the incoming request. SA determines the requester port by the SLID and SGID field of the request. SGID spoofing is when the SGID and SLID do not match.

When sa_check_sgid_spoofing parameter is enabled, SA checks for SGID spoofing in every request that includes GRH, unless the SLID belongs to a router port in that same request. In case the request SGID does not match its SLID, the request will be dropped. The default value of this parameter is TRUE.

### 7. Configuration file parameters - values example

sa_enhanced_trust_model FALSE
sa_etm_allow_untrusted_proxy_requests FALSE
sa_etm_allow_untrusted_guidinfo_rec FALSE
sa_etm_allow_guidinfo_rec_by_vf FALSE
sa_etm_max_num_mcgs 128
sa_etm_max_num_srvcs 32
sa_etm_max_num_event_subs 32
sa_rate_threshold 0
sa_check_sgid_spoofing TRUE

## Key Manager

### 1. OpenSM configuration parameters

```
1.1 key_mgr_seed – used by the SM for calculating the keys.
1.2 gmp_traps_threads_num – number of threads handling gmp key violation traps.
```

### 2. Configuration file parameters - values example

```
key_mgr_seed 0x0000000000000001
gmp_traps_threads_num 1
```

### 3. CC Key
Security feature for Congestion Control (CC) Class 0x21. The Subnet Manager configures a unique CC key for each port of the subnet that support Congestion Control Class and CC key feature.
The scope of protection is defined by OpenSM configuration file parameters, as described below. 
Once feature is enabled, device that receives MADs of the protected scope that hold incorrect key, informs the Subnet Manager of the key violation (for more information see 3.1.2 cc_key_lease_period).

If CC Key feature is enabled, Congestion Control configuration MADs should be sent with the correct CC Key. Hence, once CC Key is configured for a port, only then Congestion Control can be configured for it as well. 

#### 1. OpenSM configuration parameters

1.1 cc_key_enable

- 0 ignore – no key configuration MADs are sent.
- 1 disable – configure subnet ports to hold 0 values for CC key, lease period and protection bits. Meaning no protection is provided.
- 2 enable – configure key for each port. Set lease period and protection level as defined by cc_key_lease_period, cc_key_protect_bit, cc_key_enable attributes.

1.2 cc_key_lease_period

Lease period, in seconds. When device receives a MAD with incorrect key, it reports to the Subnet Manager and waits cc_key_lease_period seconds for response:

- If no response is received before the period passed, device will no longer be protected by the key. Hence, new CC Manager is able to reconfigure the CC keys after about cc_key_lease_period seconds.
- If response is received, meaning the SM sends TrapRepress and CC KeyInfo Set, then the key protection remains.

If set to 0, lease period is infinite.

1.3 cc_key_protect_bit

The protection level used for CC Keys protection. Supported values are:

- 0 - Protection is provided. However, CC managers can read the key by KeyInfo GET.
- 1 - Protection is provided for all CC MADs.

Please notice that the above is accurate as long as non-zero keys were configured for the ports of the subnet (cc_key_enable is 2). For ports with key zero, no protection is provided.

1.4 cc_max_outstanding_mads

Maximum number of CC class MADs in the network at once.

#### 2. Configuration file parameters - values example

```
cc_key_enable 2
cc_key_lease_period 10
cc_key_protect_bit 1
cc_max_outstanding_mads 500
```

### 4. VS Key

Security feature for Vendor Specific (VS) Class 0xA. The Subnet Manager configures a unique VS key for each port of the subnet that support Vendor Specific Classes and VS key feature.
The scope of protection is defined by OpenSM configuration file parameters, as described below. 
Once feature is enabled, device that receives MADs of the protected scope that hold incorrect key, informs the Subnet Manager of the key violation (for more information see 4.1.2 vs_key_lease_period).

#### 1. OpenSM configuration parameters

1.1 vs_key_enable

- 0 ignore – no key configuration MADs are sent.
- 1 disable – configure subnet ports to hold 0 values for VS key, lease period and protection bits. Meaning no protection is provided.
- 2 enable – configure key for each port. Set lease period and protection level as defined by- vs_key_lease_period, vs_key_ci_protect_bits, vs_key_enable attributes.

1.2 vs_key_lease_period

Lease period, in seconds. When device receives a MAD with incorrect key, it reports to the Subnet Manager and waits vs_key_lease_period seconds for a response:

- If no response is received before the period passed, device will no longer be protected by the VS key. Hence, new VS Manager is able to reconfigure the VS keys after about vs_key_lease_period seconds.
- If response is received, meaning the SM sends TrapRepress and VS KeyInfo Set, then the key protection remains.
If set to 0, lease period is infinite.

1.3 vs_key_ci_protect_bits

The protection level used for VS Keys protection, defined by both VS protect bit and protection scope. Supported values are:

- 0 - Protection is provided. However, VS managers can read the key by KeyInfo GET.
- 1 - Protection is provided for all VS MADs.
Please notice that the above is accurate as long as non-zero keys were configured for the ports of the subnet (vs_key_enable is 2). For ports with key zero, no protection is provided.

#### 2. Configuration file parameters - values example

```
vs_key_enable 2
vs_key_lease_period 60
vs_key_ci_protect_bits 1
vs_max_outstanding_mads 500
```

### Traps

Key violation is occurred once a port receives a MAD with incorrect key (e.g. Class 0xA MAD with incorrect VS Key on MAD header). The port reports to the Subnet Manager (SM), then the SM sends TrapRepress and KeyInfo Set (for the relevant key Class) to the offended port.
In addition, SM reports the key violation event. However, if the key violation was received from the same requester many times consecutively, OpenSM reports it only if the request number is part of the following sequence:
0, 1, 2, 5, 10, 20, 50, 100, 200... (similar to the trap log repression and SAETM logging).
